@@ -2,6 +2,10 @@
 #
 # Author:
 #  Tamas Jos (@skelsec)
+# 
+# Kudos:
+#  Processus Thief (@ProcessusT)
+#
 #
 
 import os
@@ -23,9 +27,13 @@ from pypykatz.dpapi.structures.blob import DPAPI_BLOB
 from pypykatz.dpapi.structures.vault import VAULT_VCRD, VAULT_VPOL, VAULT_VPOL_KEYS
 from unicrypto.hashlib import md4 as MD4
 from unicrypto.symmetric import AES, MODE_GCM, MODE_CBC
-
+from winacl.dtyp.wcee.pvkfile import PVKFile
 from pypykatz.commons.common import UniversalEncoder
 
+
+from cryptography.hazmat.primitives.asymmetric.padding import PKCS1v15
+
+
 if platform.system().lower() == 'windows':
 	from pypykatz.commons.winapi.processmanipulator import ProcessManipulator
 
@@ -334,6 +342,20 @@ class DPAPI:
 					self.prekeys[bytes.fromhex(shahex)] = 1
 				
 		return self.masterkeys
+
+	def decrypt_masterkey_file_with_pvk(self, mkffile, pvkfile):
+		"""
+		Decrypting the masterkeyfile using the domain backup key in .pvk format
+		"""
+		with open(mkffile, 'rb') as fp:
+			data = fp.read()
+		mkf = MasterKeyFile.from_bytes(data)
+		dk = mkf.domainkey.secret
+		privkey = PVKFile.from_file(pvkfile).get_key()
+		decdk = privkey.decrypt(dk[::-1], PKCS1v15())
+		secret = decdk[8:72] # TODO: proper file format would be good here!!!
+		self.masterkeys[mkf.guid] = secret
+		return self.masterkeys
 			
 	def decrypt_masterkey_file(self, file_path, key = None):
 		"""
@@ -637,7 +659,7 @@ class DPAPI:
 		return db_paths
 	
 	@staticmethod
-	def get_chrome_encrypted_secret(db_path):
+	def get_chrome_encrypted_secret(db_path, dbtype):
 		results = {}
 		results['logins'] = []
 		results['cookies'] = []
@@ -650,7 +672,7 @@ class DPAPI:
 			logger.debug('Failed to open chrome DB file %s' % db_path)
 			return results
 		
-		if ntpath.basename(db_path).lower() == 'cookies':
+		if dbtype.lower() == 'cookies':
 			try:
 				#totally not stolen from here https://github.com/byt3bl33d3r/chrome-decrypter/blob/master/chrome_decrypt.py
 				cursor.execute('SELECT host_key, name, path, encrypted_value FROM cookies')
@@ -661,7 +683,7 @@ class DPAPI:
 			for host_key, name, path, encrypted_value in cursor.fetchall():
 				results['cookies'].append((host_key, name, path, encrypted_value))
 
-		elif ntpath.basename(db_path).lower() == 'login data':
+		elif dbtype.lower() == 'logindata':
 
 			try:
 				#totally not stolen from here https://github.com/byt3bl33d3r/chrome-decrypter/blob/master/chrome_decrypt.py
@@ -680,7 +702,10 @@ class DPAPI:
 		return self.decrypt_all_chrome(dbpaths)
 		
 		
-	def decrypt_all_chrome(self, dbpaths):
+	def decrypt_all_chrome(self, dbpaths, throw = False):
+		from unicrypto import use_library, get_cipher_by_name
+		AES = get_cipher_by_name('AES', 'cryptography')
+
 		results = {}
 		results['logins'] = []
 		results['cookies'] = []
@@ -696,17 +721,19 @@ class DPAPI:
 				try:
 					localstate_dec = self.decrypt_blob_bytes(encrypted_key[5:])
 				except:
+					if throw is True:
+						raise Exception('LocalState decryption failed!')
 					# this localstate was encrypted for another user...
 					continue
 			if 'cookies' in dbpaths[username]:
-				secrets = DPAPI.get_chrome_encrypted_secret(dbpaths[username]['cookies'])
+				secrets = DPAPI.get_chrome_encrypted_secret(dbpaths[username]['cookies'], 'cookies')
 				for host_key, name, path, encrypted_value in secrets['cookies']:
 					if encrypted_value.startswith(b'v10'):
 						nonce = encrypted_value[3:3+12]
 						ciphertext = encrypted_value[3+12:-16]
 						tag = encrypted_value[-16:]
-						cipher = AES(localstate_dec, MODE_GCM)
-						dec_val = cipher.decrypt(nonce, ciphertext, tag, auth_data=b'')
+						cipher = AES(localstate_dec, MODE_GCM, IV=nonce, segment_size = 16)
+						dec_val = cipher.decrypt(ciphertext, b'', tag)
 						results['cookies'].append((dbpaths[username]['cookies'], host_key, name, path, dec_val ))
 						results['fmtcookies'].append(DPAPI.cookieformatter('https://' + host_key, name, path, dec_val))
 					else:
@@ -715,19 +742,19 @@ class DPAPI:
 						results['fmtcookies'].append(DPAPI.cookieformatter('https://' + host_key, name, path, dec_val))
 
 			if 'logindata' in dbpaths[username]:
-				secrets = DPAPI.get_chrome_encrypted_secret(dbpaths[username]['logindata'])
+				secrets = DPAPI.get_chrome_encrypted_secret(dbpaths[username]['logindata'], 'logindata')
 				for url, user, enc_password in secrets['logins']:
 					if enc_password.startswith(b'v10'):
 						nonce = enc_password[3:3+12]
 						ciphertext = enc_password[3+12:-16]
 						tag = enc_password[-16:]
-						cipher = AES(localstate_dec, MODE_GCM)
-						password = cipher.decrypt(nonce, ciphertext, tag, auth_data=b'')
+						cipher = AES(localstate_dec, MODE_GCM, IV=nonce, segment_size = 16)
+						password = cipher.decrypt(ciphertext, b'', tag)
 						results['logins'].append((dbpaths[username]['logindata'], url, user, password))
 					
 					else:
 						password = self.decrypt_blob_bytes(enc_password)
-						results['logins'].append((dbpaths[username]['logindata'], url, user, password ))
+						results['logins'].append((dbpaths[username]['logindata'], url, user, password))
 				
 		return results
 		
@@ -826,6 +853,7 @@ class DPAPI:
 		}
 
 
+
 # arpparse helper
 def prepare_dpapi_live(methods = [], mkf = None, pkf = None):
 	dpapi = DPAPI()
@@ -842,4 +870,14 @@ def prepare_dpapi_live(methods = [], mkf = None, pkf = None):
 	if 'lsass' in methods and 'all' not in methods:
 		dpapi.get_masterkeys_from_lsass_live()
 	
-	return dpapi
\ No newline at end of file
+	return dpapi
+
+def main():
+	mkffile = '/mnt/hgfs/!SHARED/feature/masterkeyfile - 170d0d57-e0ae-4877-bab6-6f5af49d3e8e'
+	pvkfile = '/mnt/hgfs/!SHARED/feature/pvkfile - ntds_capi_0_fdf0c850-73d3-48cf-86b6-6beb609206c3.keyx.rsa.pvk'
+	dpapi = DPAPI()
+	dpapi.decrypt_mkf_with_pvk(mkffile, pvkfile)
+
+
+if __name__ == '__main__':
+	main()
\ No newline at end of file
